<?php

namespace FiloBlu\FreeShippingOrderInfo\Helper;

/**
 * Class Order
 * @package FiloBlu\FreeShippingOrderInfo\Helper
 */
class Order
{
    /**
     * @var \Psr\Log\LoggerInterface
     */
    protected $logger;

    /**
     * @var \Magento\SalesRule\Model\RuleFactory
     */
    protected $ruleFactory;

    /**
     * SetIsFreeShippingCouponObserver constructor.
     * @param \Magento\SalesRule\Model\RuleFactory
     * @param \Psr\Log\LoggerInterface $logger
     */
    public function __construct(
        \Magento\SalesRule\Model\RuleFactory $ruleFactory,
        \Psr\Log\LoggerInterface $logger)
    {
        $this->logger = $logger;
        $this->ruleFactory = $ruleFactory;
    }

    /**
     * @param \Magento\Sales\Model\Order $order
     * @param boolean $save
     * @return boolean return true if is free shipping false otherwise
     */
    public function updateFreeShippingFlag($order, $save = true)
    {
        foreach (explode(',', $order->getAppliedRuleIds()) as $ruleId) {

            /** @var Magento\SalesRule\Model\Rule $rule */
            $rule = $this->ruleFactory->create()->load($ruleId);

            if (!$rule->getRuleId()) {
                continue;
            }

            $isFreeShipping = $rule->getSimpleFreeShipping();

            if (!$isFreeShipping) {
                continue;
            }

            $order->setIsFreeShippingCoupon($isFreeShipping);

            if ($save) {
                $order->save();
            }

            return true;
        }

        return false;
    }
}